@@ -5,7 +5,7 @@ use Carp qw/croak carp/;
 use Scalar::Util qw/blessed weaken/;
 use Mojo::Base 'Mojo::DOM';
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 sub DESTROY;
 
@@ -962,6 +962,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 XML::Loy - Extensible XML Reader and Writer
@@ -1430,6 +1432,11 @@ For similar scope, but without dependencies aside the core,
 try L<XML::MyXML>.
 
 
+=head1 CONTRIBUTORS
+
+L<Renée Bäcker|https://github.com/reneeb>
+
+
 =head1 AVAILABILITY
 
   https://github.com/Akron/XML-Loy
